@@ -7,34 +7,12 @@ import termcolor
 duration_s = float(sys.argv[1])
 duration_ms = int(duration_s * 1000)
 
-client_id = os.environ["SPOTIPY_CLIENT_ID"]
-client_secret = os.environ["SPOTIPY_CLIENT_SECRET"]
-cache_path = os.path.join(os.environ["XDG_RUNTIME_DIR"], ".spcache")
-
-redirect_uri = "http://localhost:8888/callback/"
-scope = (
+from main import spotipy, auth_manager
+auth_manager.scope = (
     "user-read-playback-position user-read-playback-state user-modify-playback-state"
 )
 
-auth_manager = spotipy.oauth2.SpotifyOAuth(
-    client_id=client_id,
-    client_secret=client_secret,
-    redirect_uri=redirect_uri,
-    scope=scope,
-    cache_path=cache_path,
-)
-
 sp = spotipy.Spotify(auth_manager=auth_manager)
-track = sp.current_user_playing_track()
-token = auth_manager.get_cached_token()
-access_token = token["access_token"]
-
-headers = {
-    "Authorization": f"Bearer {access_token}",
-    "Content-Type": "application/json",
-}
-BASE_URL = "https://api.spotify.com/v1/"
-
 
 playback = sp.current_playback()
 
